\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{bpamart}[2023/10/21 Bulletin of Physics and Applied Mathematics article class]

%Class options
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[twoside,11pt]{article}

%Page geometry
\RequirePackage{calc}
\setlength{\paperwidth}{21cm}
\setlength{\paperheight}{29.7cm}
\setlength{\textwidth}{14cm}
\setlength{\textheight}{21cm}
\setlength{\headheight}{1cm}
\setlength{\headsep}{1cm}
\setlength{\footskip}{1.5cm}
\setlength{\topmargin}{(\paperheight-\textheight-\headheight-\headsep-\footskip)/2 - 1in}
\setlength{\oddsidemargin}{(\paperwidth-\textwidth)/2 - 1in}
\setlength{\evensidemargin}{\oddsidemargin}

%Class-specific variables: year, volume, article number, short author name, short title
\newcommand{\bpamyear}[1]{\gdef\@bpamyear{#1}}
\newcommand{\bpamartnum}[1]{\gdef\@bpamartnum{#1}}
\newcommand{\bpamvol}[1]{\gdef\@bpamvol{#1}}
\newcommand{\bpamshauth}[1]{\gdef\@bpamshauth{#1}}
\newcommand{\bpamshtitl}[1]{\gdef\@bpamshtitl{#1}}

%Standard font for headings
\newcommand{\bpamfont}{ 
    \fontencoding{T1}
    \fontfamily{ptm}
    \selectfont 
}

%authblk is used to manage authors
\RequirePackage{authblk}
\renewcommand{\Authfont}{\bpamfont \scshape}
\renewcommand{\Affilfont}{\bpamfont}
\renewcommand\Authsep{, }
\renewcommand\Authand{, }
\renewcommand\Authands{, }

%maketitle, abstract and keywords redefinition
\NewCommandCopy{\origtitle}{\title}
\renewcommand{\title}[1]{
\origtitle{
    \bpamfont
    \bfseries
    \Large
    \MakeUppercase{#1}
    }
}
\renewcommand{\maketitle}{
    \par
    \begingroup%
        \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
        \def\@makefnmark{{\@textsuperscript{\normalfont\@thefnmark}}}%
        \long\def\@makefntext##1{\parindent 1em\noindent
        \hb@xt@1.8em{%
        \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%    
        \newpage
        %\null
        %\vskip 1em%
        \begin{center}%
            {\large \AB@authlist \par}
            \vskip 1em
            \let \footnote \thanks
            {\LARGE \@title \par}%
            \vskip 1.5em%
            {\scriptsize \AB@affillist \par}%
            \vskip 0.5em%
            %{\footnotesize \itshape \@date}%
        \end{center}%
        \par
        \vskip 0.5em
        \thispagestyle{bpamfirst}
        \@thanks
    \endgroup
}
\renewenvironment{abstract}{%
    \small
%    \begin{center}%
%    {\bfseries \abstractname
%    \vspace{-.5em}\vspace{\z@}}%
%    \end{center}%
     \quote \itshape 
}
{
    \endquote
    \vskip 1em
}
\providecommand{\keywords}[1]
{
  \small	
  \textbf{\bpamfont Keywords:} #1
}

%Sections and subsections
\RequirePackage{titlesec}
\titleformat{\section}
{
    \filcenter
    \bpamfont
    \bfseries
    \large
}{\thesection.}{0.5em}{\MakeUppercase}
\titleformat{\subsection}
{
    \bpamfont
    \large
    \bfseries}
{\thesubsection.}{0.5em}{}
\titleformat{\subsubsection}
{
    \bpamfont
    \normalsize
    \itshape
}{\thesubsubsection. }{0.5em}{}

%Figure captions
\RequirePackage{caption}
\DeclareCaptionFont{bpam}{
\bpamfont 
\bfseries}
\captionsetup{
font=bpam, 
textfont={normalfont,it},
labelsep=period
}

%Page headers and footers 
\RequirePackage{fancyhdr}
\fancypagestyle{bpamplain}{%
\fancyhf{}
\fancyhead{}
\fancyhead[LE]{\bpamfont  \small \@bpamshauth}
\fancyhead[LO]{\bpamfont  \small \@bpamshtitl}
\fancyhead[R]{\bpamfont \small \textsc{BPAM} \textbf{\@bpamvol}, \@bpamartnum\ (\@bpamyear)}
\fancyfoot[C]{\thepage}
}
\fancypagestyle{bpamfirst}{%
\fancyhf{}
\fancyhead{}
\fancyhead[C]{\bpamfont \textsc{\normalsize Bulletin of Physics and Applied Mathematics} \textbf{\@bpamvol}, \@bpamartnum\ (\@bpamyear)}
\fancyfoot[C]{\thepage}
\fancyfoot[R]{\footnotesize \raisebox{0.1em}{\tiny\copyright}\@bpamyear\ {\itshape Lodz University of Technology} }
}
\pagestyle{bpamplain}
